@@ -18,7 +18,7 @@ from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import FieldTypeType, RelatedItemTypeType
+from .literals import FieldTypeType, RelatedItemTypeType, TemplateStatusType
 from .paginator import SearchCasesPaginator, SearchRelatedItemsPaginator
 from .type_defs import (
     BatchGetFieldResponseTypeDef,
@@ -206,7 +206,8 @@ class ConnectCasesClient(BaseClient):
         name: str,
         description: str = ...,
         layoutConfiguration: LayoutConfigurationTypeDef = ...,
-        requiredFields: Sequence[RequiredFieldTypeDef] = ...
+        requiredFields: Sequence[RequiredFieldTypeDef] = ...,
+        status: TemplateStatusType = ...
     ) -> CreateTemplateResponseTypeDef:
         """
         Creates a template in the Cases domain.
@@ -343,7 +344,12 @@ class ConnectCasesClient(BaseClient):
         """
 
     def list_templates(
-        self, *, domainId: str, maxResults: int = ..., nextToken: str = ...
+        self,
+        *,
+        domainId: str,
+        maxResults: int = ...,
+        nextToken: str = ...,
+        status: Sequence[TemplateStatusType] = ...
     ) -> ListTemplatesResponseTypeDef:
         """
         Lists all of the templates in a Cases domain.
@@ -451,7 +457,8 @@ class ConnectCasesClient(BaseClient):
         description: str = ...,
         layoutConfiguration: LayoutConfigurationTypeDef = ...,
         name: str = ...,
-        requiredFields: Sequence[RequiredFieldTypeDef] = ...
+        requiredFields: Sequence[RequiredFieldTypeDef] = ...,
+        status: TemplateStatusType = ...
     ) -> Dict[str, Any]:
         """
         Updates the attributes of an existing template.
