@@ -21,6 +21,7 @@ from .literals import (
     FieldTypeType,
     OrderType,
     RelatedItemTypeType,
+    TemplateStatusType,
 )
 
 if sys.version_info >= (3, 9):
@@ -496,6 +497,7 @@ _OptionalListTemplatesRequestRequestTypeDef = TypedDict(
     {
         "maxResults": int,
         "nextToken": str,
+        "status": Sequence[TemplateStatusType],
     },
     total=False,
 )
@@ -511,6 +513,7 @@ TemplateSummaryTypeDef = TypedDict(
     "TemplateSummaryTypeDef",
     {
         "name": str,
+        "status": TemplateStatusType,
         "templateArn": str,
         "templateId": str,
     },
@@ -778,6 +781,7 @@ _OptionalCreateTemplateRequestRequestTypeDef = TypedDict(
         "description": str,
         "layoutConfiguration": LayoutConfigurationTypeDef,
         "requiredFields": Sequence[RequiredFieldTypeDef],
+        "status": TemplateStatusType,
     },
     total=False,
 )
@@ -796,6 +800,7 @@ GetTemplateResponseTypeDef = TypedDict(
         "layoutConfiguration": LayoutConfigurationTypeDef,
         "name": str,
         "requiredFields": List[RequiredFieldTypeDef],
+        "status": TemplateStatusType,
         "tags": Dict[str, str],
         "templateArn": str,
         "templateId": str,
@@ -817,6 +822,7 @@ _OptionalUpdateTemplateRequestRequestTypeDef = TypedDict(
         "layoutConfiguration": LayoutConfigurationTypeDef,
         "name": str,
         "requiredFields": Sequence[RequiredFieldTypeDef],
+        "status": TemplateStatusType,
     },
     total=False,
 )
